==> speech-analytic-testing_0.23.0_database.tar.gz: database/mssql/procedures/SaveUnderlined.sql <==
SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO
-- [dbo].[SaveUtterance] 'allegro', '4bad9174-ea84-45ee-ab2f-b17c73c43734', '45799dd8-17e7-49a1-9bd8-cb74f00a788c', '{f2c9e160-8eeb-11e9-8562-b65bb2fb6bcb}', 0, 1, 'in', 10, 14, 1.23, 1.38, 0, 'hola', '2019-08-02 15:30:00.000', 'analytic', NULL, NULL
CREATE PROCEDURE [dbo].[SaveUnderlined]
(
	@VCC						VARCHAR(50),
	@AppId						VARCHAR(50),
	@IntentId					VARCHAR(50),
	@AudioId					VARCHAR(50),
	@Section					NUMERIC(5, 0),
	@Part						NUMERIC(5, 0),
	@Speaker					VARCHAR(3),
	@AnchorOffset				INT,
	@FocusOffset				INT,
	@CurrentTime				FLOAT,
	@EndCurrentTime				FLOAT,
	@UtteranceId				NUMERIC(18, 0),
	@TextContent				VARCHAR(500),
	@CreatedDate				DATETIME,
	@CreatedByUserId			VARCHAR(50),
	@LastModifiedDate			DATETIME,
	@LastModifiedByUserId		VARCHAR(50)
)
AS
BEGIN
	SET NOCOUNT ON

	-- EN CASO LLEGUE COMO NULL LO IGUALAMOS A 0
	IF @Section IS NULL BEGIN SET @Section = 0 END 

	UPDATE [dbo].Underlined SET
		[VCC] = @VCC,
		[AudioId] = @AudioId,
		[Section] = @Section,
		[Part] = @Part,
		[Speaker] = @Speaker,
		[AnchorOffset] = @AnchorOffset,
		[FocusOffset] = @FocusOffset,
		[CurrentTime] = @CurrentTime,
		[EndCurrentTime] = @EndCurrentTime,
		[UtteranceId] = @UtteranceId,
		[CreatedDate] = @CreatedDate,
		[CreatedByUserId] = @CreatedByUserId,
		[LastModifiedDate] = @LastModifiedDate,
		[LastModifiedByUserId] = @LastModifiedByUserId,
		[TimeStamp] = GETUTCDATE()
	WHERE
		[VCC] = @VCC
	    AND [UtteranceId] = @UtteranceId
		AND [AudioId] = @AudioId
		AND [Section] = @Section
		AND [Part] = @Part

	IF @@ROWCOUNT = 0
	BEGIN
		INSERT INTO [dbo].[Underlined] (
			[VCC],
			[AudioId],
			[Section],
			[Part],
			[Speaker],
			[AnchorOffset],
			[FocusOffset],
			[CurrentTime],
			[EndCurrentTime],
			[UtteranceId],
			[CreatedDate],
			[CreatedByUserId],
			[LastModifiedDate],
			[LastModifiedByUserId],
			[TimeStamp]
		)
		VALUES(
			@VCC,
			@AudioId,
			@Section,
			@Part,
			@Speaker,
			@AnchorOffset,
			@FocusOffset,
			@CurrentTime,
			@EndCurrentTime,
			@UtteranceId,
			@CreatedDate,
			@CreatedByUserId,
			@LastModifiedDate,
			@LastModifiedByUserId,
			GETUTCDATE()
		)
	END

	SELECT 1 AS 'result'

	SET NOCOUNT OFF
END
GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS OFF 
GO

GO

==> speech-analytic-testing_5.2.11_database.tar.gz: database/mssql/procedures/SaveUnderlined.sql <==
SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO
-- [dbo].[SaveUtterance] 'allegro', '4bad9174-ea84-45ee-ab2f-b17c73c43734', '45799dd8-17e7-49a1-9bd8-cb74f00a788c', '{f2c9e160-8eeb-11e9-8562-b65bb2fb6bcb}', 0, 1, 'in', 10, 14, 1.23, 1.38, 0, 'hola', '2019-08-02 15:30:00.000', 'analytic', NULL, NULL
CREATE PROCEDURE [dbo].[SaveUnderlined]
(
	@VCC						VARCHAR(50),
	@AppId						VARCHAR(50),
	@IntentId					VARCHAR(50),
	@AudioId					VARCHAR(50),
	@Section					NUMERIC(5, 0),
	@Part						NUMERIC(5, 0),
	@Speaker					VARCHAR(3),
	@AnchorOffset				INT,
	@FocusOffset				INT,
	@CurrentTime				FLOAT,
	@EndCurrentTime				FLOAT,
	@UtteranceId				VARCHAR(50),
	@TextContent				VARCHAR(500),
	@CreatedDate				DATETIME,
	@CreatedByUserId			VARCHAR(50),
	@LastModifiedDate			DATETIME,
	@LastModifiedByUserId		VARCHAR(50)
)
AS
BEGIN
	SET NOCOUNT ON

	-- EN CASO LLEGUE COMO NULL LO IGUALAMOS A 0
	IF @Section IS NULL BEGIN SET @Section = 0 END 

	UPDATE [dbo].Underlined SET
		[VCC] = @VCC,
		[AudioId] = @AudioId,
		[Section] = @Section,
		[Part] = @Part,
		[Speaker] = @Speaker,
		[AnchorOffset] = @AnchorOffset,
		[FocusOffset] = @FocusOffset,
		[CurrentTime] = @CurrentTime,
		[EndCurrentTime] = @EndCurrentTime,
		[UtteranceId] = @UtteranceId,
		[CreatedDate] = @CreatedDate,
		[CreatedByUserId] = @CreatedByUserId,
		[LastModifiedDate] = @LastModifiedDate,
		[LastModifiedByUserId] = @LastModifiedByUserId,
		[TimeStamp] = GETUTCDATE()
	WHERE
		[VCC] = @VCC
	    AND [UtteranceId] = @UtteranceId
		AND [AudioId] = @AudioId
		AND [Section] = @Section
		AND [Part] = @Part

	IF @@ROWCOUNT = 0
	BEGIN
		INSERT INTO [dbo].[Underlined] (
			[VCC],
			[AudioId],
			[Section],
			[Part],
			[Speaker],
			[AnchorOffset],
			[FocusOffset],
			[CurrentTime],
			[EndCurrentTime],
			[UtteranceId],
			[CreatedDate],
			[CreatedByUserId],
			[LastModifiedDate],
			[LastModifiedByUserId],
			[TimeStamp]
		)
		VALUES(
			@VCC,
			@AudioId,
			@Section,
			@Part,
			@Speaker,
			@AnchorOffset,
			@FocusOffset,
			@CurrentTime,
			@EndCurrentTime,
			@UtteranceId,
			@CreatedDate,
			@CreatedByUserId,
			@LastModifiedDate,
			@LastModifiedByUserId,
			GETUTCDATE()
		)
	END

	SELECT 1 AS 'result'

	SET NOCOUNT OFF
END
GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS OFF 
GO

GO
